@@ -38,7 +38,7 @@ pub enum Direction {
 }
 
 impl Direction {
-    fn to_f32(&self) -> f32 {
+    pub fn to_f32(&self) -> f32 {
         if *self == Direction::Normal {
             1.0
         } else {
@@ -135,45 +135,45 @@ pub fn io_orientations(affine: &Affine) -> Orientations {
     orientations
 }
 
-/// Convert orientation `orientations` to labels for axis directions
+/// Convert `orientations` to labels for axis directions
+///
+/// The "identity" orientation is RAS. Thus, calling this function with
+///
+/// `[(0, Direction::Normal), (1, Direction::Normal), (2, Direction::Normal)]`
+///
+/// would return "RAS".
 pub fn orientations_to_axcodes(orientations: Orientations) -> String {
-    let labels = [
-        ("L".to_string(), "R".to_string()),
-        ("P".to_string(), "A".to_string()),
-        ("I".to_string(), "S".to_string()),
-    ];
-
+    let labels = [['R', 'L'], ['A', 'P'], ['S', 'I']];
     orientations
-        .iter()
-        .map(|&(ref axis, ref direction)| {
-            if *direction == Direction::Normal {
-                labels[*axis].1.clone()
-            } else {
-                labels[*axis].0.clone()
-            }
-        })
-        .collect::<Vec<_>>()
-        .join("")
+        .into_iter()
+        .map(|(axis, direction)| labels[axis][(direction == Direction::Reversed) as usize])
+        .collect()
 }
 
 /// Convert axis codes `axcodes` to an orientation
+///
+/// The "identity" orientation is RAS. Thus, calling this function with "RAS" would return
+///
+/// `[(0, Direction::Normal), (1, Direction::Normal), (2, Direction::Normal)]`
+///
+/// If the caller has a different default orientation, like LAS, he must reverse the `Direction` of
+/// the `0` axis.
 pub fn axcodes_to_orientations(axcodes: &str) -> Orientations {
-    let labels = [('L', 'R'), ('P', 'A'), ('I', 'S')];
+    let labels = [('R', 'L'), ('A', 'P'), ('S', 'I')];
     let mut orientations = [(0, Direction::Normal), (0, Direction::Normal), (0, Direction::Normal)];
     for (code_idx, code) in axcodes.chars().enumerate() {
         for (label_idx, codes) in labels.iter().enumerate() {
             if code == codes.0 {
-                orientations[code_idx] = (label_idx, Direction::Reversed);
-            } else if code == codes.1 {
                 orientations[code_idx] = (label_idx, Direction::Normal);
+            } else if code == codes.1 {
+                orientations[code_idx] = (label_idx, Direction::Reversed);
             }
         }
     }
     orientations
 }
 
-/// Return the orientation that transforms from `start_orientations` to
-/// `end_orientations`
+/// Return the orientation that transforms from `start_orientations` to `end_orientations`.
 pub fn orientations_transform(
     start_orientations: &Orientations,
     end_orientations: &Orientations,
@@ -222,6 +222,7 @@ where
     }
 
     // Orientation indicates the transpose that has occurred - we reverse it
+    // The following block is simply an argsort of 3 numbers.
     let mut x = (orientations[0].0, 0);
     let mut y = (orientations[1].0, 1);
     let mut z = (orientations[2].0, 2);
